@@ -201,12 +201,26 @@ class FinXRest:
         print("row", row)
         instrument_name = row['instrument_name']
         years_to_expiry = 0.0
-        day_value = instrument_name.split("-")[1][0:2]
-        month_value = instrument_name.split("-")[1][2:5]
-        year_value = instrument_name.split("-")[1][5:8]
-        date_string = year_value + '/' + month_value + '/' + day_value
-        expiry_unix = datetime.datetime.strptime(date_string, '%y/%b/%d').timestamp()
-        years_to_expiry = (expiry_unix - time.time()) / 60 / 60 / 24 / 365
+        try:
+            day_value = int(instrument_name.split("-")[1][0:2])
+            month_value = instrument_name.split("-")[1][2:5]
+            year_value = int(instrument_name.split("-")[1][5:8])
+            date_string = str(year_value) + '/' + month_value + '/' + str(day_value)
+            expiry_unix = datetime.datetime.strptime(date_string, '%y/%b/%d').timestamp()
+        except:
+            return None
+        try:
+            day_value = int(instrument_name.split("-")[1][0:1])
+            month_value = instrument_name.split("-")[1][1:4]
+            year_value = int(instrument_name.split("-")[1][4:7])
+            date_string = str(year_value) + '/' + month_value + '/' + str(day_value)
+            expiry_unix = datetime.datetime.strptime(date_string, '%y/%b/%d').timestamp()
+        except:
+            return None
+        try:
+            years_to_expiry = (expiry_unix - time.time()) / 60 / 60 / 24 / 365
+        except:
+            return None
         return years_to_expiry
 
     def _parse_strike_price(self, row):
